@@ -5,7 +5,6 @@ import (
 
 	"github.com/ameshkov/dnscrypt/v2"
 	"github.com/miekg/dns"
-	"github.com/sirupsen/logrus"
 )
 
 // DNSCryptResolver represents the config options for setting up a Resolver.
@@ -43,17 +42,18 @@ func NewDNSCryptResolver(server string, dnscryptOpts DNSCryptResolverOpts, resol
 
 // Lookup takes a dns.Question and sends them to DNS Server.
 // It parses the Response from the server in a custom output format.
-func (r *DNSCryptResolver) Lookup(question dns.Question) (Response, error) {
+func (r *DNSCryptResolver) Lookup(question dns.Question, flags QueryFlags) (Response, error) {
 	var (
 		rsp      Response
-		messages = prepareMessages(question, r.resolverOptions.Ndots, r.resolverOptions.SearchList)
+		messages = prepareMessages(question, flags, r.resolverOptions.Ndots, r.resolverOptions.SearchList)
 	)
 	for _, msg := range messages {
-		r.resolverOptions.Logger.WithFields(logrus.Fields{
-			"domain":     msg.Question[0].Name,
-			"ndots":      r.resolverOptions.Ndots,
-			"nameserver": r.server,
-		}).Debug("Attempting to resolve")
+		r.resolverOptions.Logger.Debug("Attempting to resolve",
+			"domain", msg.Question[0].Name,
+			"ndots", r.resolverOptions.Ndots,
+			"nameserver", r.server,
+		)
+
 		now := time.Now()
 		in, err := r.client.Exchange(&msg, r.resolverInfo)
 		if err != nil {
