@@ -1,17 +1,17 @@
 package resolvers
 
 import (
+	"log/slog"
 	"time"
 
 	"github.com/miekg/dns"
 	"github.com/mr-karan/doggo/pkg/models"
-	"github.com/sirupsen/logrus"
 )
 
 // Options represent a set of common options
 // to configure a Resolver.
 type Options struct {
-	Logger *logrus.Logger
+	Logger *slog.Logger
 
 	Nameservers        []models.Nameserver
 	UseIPv4            bool
@@ -28,7 +28,7 @@ type Options struct {
 // Client. Different types of providers can load
 // a DNS Resolver satisfying this interface.
 type Resolver interface {
-	Lookup(dns.Question) (Response, error)
+	Lookup(dns.Question, QueryFlags) (Response, error)
 }
 
 // Response represents a custom output format
